@@ -1,6 +1,7 @@
 #! /usr/bin/env python
+# -*- coding: iso-8859-1 -*-
 # vi:ts=4:et
-# $Id: test_multi5.py,v 1.5 2002/08/29 14:39:21 mfx Exp $
+# $Id$
 
 import sys, select, time
 import pycurl
@@ -8,12 +9,12 @@ import pycurl
 c1 = pycurl.Curl()
 c2 = pycurl.Curl()
 c3 = pycurl.Curl()
-c1.setopt(c1.URL, 'http://www.python.org')
-c2.setopt(c2.URL, 'http://curl.haxx.se')
-c3.setopt(c3.URL, 'http://slashdot.org')
-c1.body = file("doc1", "w")
-c2.body = file("doc2", "w")
-c3.body = file("doc3", "w")
+c1.setopt(c1.URL, "http://www.python.org")
+c2.setopt(c2.URL, "http://curl.haxx.se")
+c3.setopt(c3.URL, "http://slashdot.org")
+c1.body = open("doc1", "wb")
+c2.body = open("doc2", "wb")
+c3.body = open("doc3", "wb")
 c1.setopt(c1.WRITEFUNCTION, c1.body.write)
 c2.setopt(c2.WRITEFUNCTION, c2.body.write)
 c3.setopt(c3.WRITEFUNCTION, c3.body.write)
@@ -24,12 +25,13 @@ m.add_handle(c2)
 m.add_handle(c3)
 
 # Number of seconds to wait for a timeout to happen
-SELECT_TIMEOUT = 10
+SELECT_TIMEOUT = 1.0
 
 # Stir the state machine into action
 while 1:
     ret, num_handles = m.perform()
-    if ret != pycurl.CALL_MULTI_PERFORM: break
+    if ret != pycurl.E_CALL_MULTI_PERFORM:
+        break
 
 # Keep going until all the connections have terminated
 while num_handles:
@@ -38,7 +40,8 @@ while num_handles:
     m.select(SELECT_TIMEOUT)
     while 1:
         ret, num_handles = m.perform()
-        if ret != pycurl.CALL_MULTI_PERFORM: break
+        if ret != pycurl.E_CALL_MULTI_PERFORM:
+            break
 
 # Cleanup
 m.remove_handle(c3)
@@ -51,3 +54,7 @@ c3.body.close()
 c1.close()
 c2.close()
 c3.close()
+print "http://www.python.org is in file doc1"
+print "http://curl.haxx.se is in file doc2"
+print "http://slashdot.org is in file doc3"
+
